# Description
Helpfull scripts for doing computational chemistry

# Latest updates
Support for orca input file creation\
Customizable use of .com or .gjf extensions\
Bug fixes and other customizations

# Installing
On Windons:
```bash
py -m pip install raachem
```
On Linux:
```bash
python3 -m pip install raachem
```

# Running
After installation is complete, you should be able to run the module from any folder using one of the following:
On Windons:
```bash
py -m raachem
```
On Linux:
```bash
python3 -m raachem
```
Done! The script operates on files in the current working directory!
